package com.ruoyi.web.controller.register;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.RegisterTeacherClass;
import com.ruoyi.system.service.IRegisterTeacherClassService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 注册-老师-班级（学科）Controller
 * 
 * @author ruoyi
 * @date 2023-05-25
 */
@RestController
@RequestMapping("/register/class")
public class RegisterTeacherClassController extends BaseController
{
    @Autowired
    private IRegisterTeacherClassService registerTeacherClassService;

    /**
     * 查询注册-老师-班级（学科）列表
     */
    @PreAuthorize("@ss.hasPermi('register:class:list')")
    @GetMapping("/list")
    public TableDataInfo list(RegisterTeacherClass registerTeacherClass)
    {
        startPage();
        List<RegisterTeacherClass> list = registerTeacherClassService.selectRegisterTeacherClassList(registerTeacherClass);
        return getDataTable(list);
    }

    /**
     * 导出注册-老师-班级（学科）列表
     */
    @PreAuthorize("@ss.hasPermi('register:class:export')")
    @Log(title = "注册-老师-班级（学科）", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, RegisterTeacherClass registerTeacherClass)
    {
        List<RegisterTeacherClass> list = registerTeacherClassService.selectRegisterTeacherClassList(registerTeacherClass);
        ExcelUtil<RegisterTeacherClass> util = new ExcelUtil<RegisterTeacherClass>(RegisterTeacherClass.class);
        util.exportExcel(response, list, "注册-老师-班级（学科）数据");
    }

    /**
     * 获取注册-老师-班级（学科）详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(registerTeacherClassService.selectRegisterTeacherClassById(id));
    }

    /**
     * 新增注册-老师-班级（学科）
     */
    @PreAuthorize("@ss.hasPermi('register:class:add')")
    @Log(title = "注册-老师-班级（学科）", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody RegisterTeacherClass registerTeacherClass)
    {
        return toAjax(registerTeacherClassService.insertRegisterTeacherClass(registerTeacherClass));
    }

    /**
     * 修改注册-老师-班级（学科）
     */
    @PreAuthorize("@ss.hasPermi('register:class:edit')")
    @Log(title = "注册-老师-班级（学科）", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody RegisterTeacherClass registerTeacherClass)
    {
        return toAjax(registerTeacherClassService.updateRegisterTeacherClass(registerTeacherClass));
    }

    /**
     * 删除注册-老师-班级（学科）
     */
    @PreAuthorize("@ss.hasPermi('register:class:remove')")
    @Log(title = "注册-老师-班级（学科）", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(registerTeacherClassService.deleteRegisterTeacherClassByIds(ids));
    }
}
